@@ -14,7 +14,7 @@ class CreditNoteEstimate(Model):
       fields = ["name", "amount", "description"]
       pass
     class LineItemTax(Model):
-      fields = ["line_item_id", "tax_name", "tax_rate", "is_partial_tax_applied", "is_non_compliance_tax", "taxable_amount", "tax_amount", "tax_juris_type", "tax_juris_name", "tax_juris_code"]
+      fields = ["line_item_id", "tax_name", "tax_rate", "is_partial_tax_applied", "is_non_compliance_tax", "taxable_amount", "tax_amount", "tax_juris_type", "tax_juris_name", "tax_juris_code", "tax_amount_in_local_currency", "local_currency_code"]
       pass
     class LineItemDiscount(Model):
       fields = ["line_item_id", "discount_type", "coupon_id", "discount_amount"]
@@ -25,5 +25,5 @@ class CreditNoteEstimate(Model):
 
     fields = ["reference_invoice_id", "type", "price_type", "currency_code", "sub_total", "total", \
     "amount_allocated", "amount_available", "line_items", "discounts", "taxes", "line_item_taxes", \
-    "line_item_discounts", "line_item_tiers", "round_off_amount"]
+    "line_item_discounts", "line_item_tiers", "round_off_amount", "customer_id"]
 
