@@ -14,7 +14,7 @@ class InvoiceEstimate(Model):
       fields = ["name", "amount", "description"]
       pass
     class LineItemTax(Model):
-      fields = ["line_item_id", "tax_name", "tax_rate", "is_partial_tax_applied", "is_non_compliance_tax", "taxable_amount", "tax_amount", "tax_juris_type", "tax_juris_name", "tax_juris_code"]
+      fields = ["line_item_id", "tax_name", "tax_rate", "is_partial_tax_applied", "is_non_compliance_tax", "taxable_amount", "tax_amount", "tax_juris_type", "tax_juris_name", "tax_juris_code", "tax_amount_in_local_currency", "local_currency_code"]
       pass
     class LineItemTier(Model):
       fields = ["line_item_id", "starting_unit", "ending_unit", "quantity_used", "unit_amount"]
@@ -25,5 +25,5 @@ class InvoiceEstimate(Model):
 
     fields = ["recurring", "price_type", "currency_code", "sub_total", "total", "credits_applied", \
     "amount_paid", "amount_due", "line_items", "discounts", "taxes", "line_item_taxes", "line_item_tiers", \
-    "line_item_discounts", "round_off_amount"]
+    "line_item_discounts", "round_off_amount", "customer_id"]
 
