@@ -20,11 +20,12 @@ class Plan(Model):
     fields = ["id", "name", "invoice_name", "description", "price", "currency_code", "period", \
     "period_unit", "trial_period", "trial_period_unit", "pricing_model", "charge_model", "free_quantity", \
     "setup_cost", "downgrade_penalty", "status", "archived_at", "billing_cycles", "redirect_url", \
-    "enabled_in_hosted_pages", "enabled_in_portal", "addon_applicability", "tax_code", "avalara_sale_type", \
-    "avalara_transaction_type", "avalara_service_type", "sku", "accounting_code", "accounting_category1", \
-    "accounting_category2", "is_shippable", "shipping_frequency_period", "shipping_frequency_period_unit", \
-    "resource_version", "updated_at", "giftable", "claim_url", "invoice_notes", "taxable", "tax_profile_id", \
-    "meta_data", "tiers", "applicable_addons", "attached_addons", "event_based_addons"]
+    "enabled_in_hosted_pages", "enabled_in_portal", "addon_applicability", "tax_code", "taxjar_product_code", \
+    "avalara_sale_type", "avalara_transaction_type", "avalara_service_type", "sku", "accounting_code", \
+    "accounting_category1", "accounting_category2", "is_shippable", "shipping_frequency_period", \
+    "shipping_frequency_period_unit", "resource_version", "updated_at", "giftable", "claim_url", \
+    "invoice_notes", "taxable", "tax_profile_id", "meta_data", "tiers", "applicable_addons", "attached_addons", \
+    "event_based_addons"]
 
 
     @staticmethod
