@@ -19,11 +19,11 @@ class Transaction(Model):
 
     fields = ["id", "customer_id", "subscription_id", "gateway_account_id", "payment_source_id", \
     "payment_method", "reference_number", "gateway", "type", "date", "settled_at", "currency_code", \
-    "amount", "id_at_gateway", "status", "fraud_flag", "authorization_reason", "error_code", "error_text", \
-    "voided_at", "resource_version", "updated_at", "fraud_reason", "amount_unused", "masked_card_number", \
-    "reference_transaction_id", "refunded_txn_id", "reference_authorization_id", "amount_capturable", \
-    "reversal_transaction_id", "linked_invoices", "linked_credit_notes", "linked_refunds", "linked_payments", \
-    "deleted"]
+    "amount", "id_at_gateway", "status", "fraud_flag", "initiator_type", "three_d_secure", "authorization_reason", \
+    "error_code", "error_text", "voided_at", "resource_version", "updated_at", "fraud_reason", "amount_unused", \
+    "masked_card_number", "reference_transaction_id", "refunded_txn_id", "reference_authorization_id", \
+    "amount_capturable", "reversal_transaction_id", "linked_invoices", "linked_credit_notes", "linked_refunds", \
+    "linked_payments", "deleted"]
 
 
     @staticmethod
@@ -34,6 +34,10 @@ class Transaction(Model):
     def void_transaction(id, env=None, headers=None):
         return request.send('post', request.uri_path("transactions",id,"void"), None, env, headers)
 
+    @staticmethod
+    def record_refund(id, params, env=None, headers=None):
+        return request.send('post', request.uri_path("transactions",id,"record_refund"), params, env, headers)
+
     @staticmethod
     def list(params=None, env=None, headers=None):
         return request.send_list_request('get', request.uri_path("transactions"), params, env, headers)
